@@ -1,9 +1,7 @@
 package Dist::Zilla::Plugin::ChangeStats::Git;
-BEGIN {
-  $Dist::Zilla::Plugin::ChangeStats::Git::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: add code churn statistics to the changelog
-$Dist::Zilla::Plugin::ChangeStats::Git::VERSION = '0.3.0';
+$Dist::Zilla::Plugin::ChangeStats::Git::VERSION = '0.4.0';
 
 use strict;
 use warnings;
@@ -47,6 +45,12 @@ has "release_branch" => (
     default => 'releases'
 );
 
+has "auto_previous_tag" => (
+    isa => 'Bool',
+    is => 'ro',
+    default => 0,
+);
+
 has group => (
     is => 'ro',
     default => '',
@@ -57,22 +61,50 @@ has stats => (
     lazy => 1,
     default => sub {
         my $self = shift;
-        
+
+	# What are we diffing against? :)
+	my( $prev, $next ) = ( $self->release_branch, $self->develop_branch );
+	if ( $self->auto_previous_tag ) {
+		$prev = $self->_get_previous_tag;
+		return if ! defined $prev;
+	}
+	$self->log_debug( "Comparing '$prev' against '$next' for code stats" );
         my @output = $self->repo->run( 'diff', '--stat',
-            join '...', $self->release_branch, $self->develop_branch
+            join '...', $prev, $next
         );
 
         # actually, only the last line is interesting
-        my $stats = "code churn: " . $output[-1];
-        $stats =~ s/\s+/ /g;
-
-        return $stats;
+	if ( defined $output[-1] ) {
+	        my $stats = "code churn: " . $output[-1];
+		$stats =~ s/\s+/ /g;
+	        return $stats;
+	} else {
+		return;
+	}
   } 
 );
 
+sub _get_previous_tag {
+	my( $self ) = @_;
+	my @plugins = grep { $_->isa('Dist::Zilla::Plugin::Git::Tag') } @{ $self->zilla->plugins_with( '-Git::Repo' ) };
+	die "We dont know what to do with multiple Git::Tag plugins loaded!" if scalar @plugins > 1;
+	die "Please load the Git::Tag plugin to use auto_release_tag or disable it!" if ! scalar @plugins;
+	(my $match = $plugins[0]->tag_format) =~ s/\%\w/\.\+/g; # hack.
+	$match = ( grep { $_ =~ /$match/ } $self->repo->run( 'tag' ) )[-1];
+	if ( ! defined $match ) {
+		$self->log( "Unable to find the previous tag, trying to find the first commit!" );
+		$match = $self->repo->run( 'rev-list', "--max-parents=0", 'HEAD' );
+		if ( ! defined $match ) {
+			$self->log( "Unable to find the first commit, giving up!" );
+			return;
+		}
+	}
+	return $match;
+}
+
 sub munge_files {
   my ($self) = @_;
-
+  return unless $self->stats;
   my $changelog = $self->zilla->changelog;
 
   my ( $next ) = reverse $changelog->releases;
@@ -85,10 +117,10 @@ sub munge_files {
 
 sub after_release {
   my $self = shift;
-
+  return unless $self->stats;
   my $changes = CPAN::Changes->load( 
       $self->zilla->changelog_name,
-      next_token => qr/{{\$NEXT}}/ 
+      next_token => qr/\{\{\$NEXT\}\}/
   ); 
 
   for my $next ( reverse $changes->releases ) {
@@ -121,7 +153,7 @@ Dist::Zilla::Plugin::ChangeStats::Git - add code churn statistics to the changel
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -147,13 +179,18 @@ If given, the line is added to the specified group.
 
 The master developing branch. Defaults to I<master>.
 
+=head2 auto_previous_tag
+
+If enabled, look in the guts of the L<Dist::Zilla::Plugin::Git::Tag> plugin in order to find the
+previous release's tag. This will be then compared against the develop_branch. Defaults to false (0).
+
 =head2 release_branch
 
 The branch recording the releases. Defaults to I<releases>.
 
 =head1 AUTHOR
 
-Yanick Champoux <yanick@babyl.dyndns.org>
+Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
