@@ -1,9 +1,7 @@
 package Dist::Zilla::Role::Author::YANICK::Changelog;
-BEGIN {
-  $Dist::Zilla::Role::Author::YANICK::Changelog::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: provides an accessor for the changelog
-$Dist::Zilla::Role::Author::YANICK::Changelog::VERSION = '0.3.0';
+$Dist::Zilla::Role::Author::YANICK::Changelog::VERSION = '0.4.0';
 use strict;
 use warnings;
 
@@ -30,7 +28,7 @@ sub changelog {
 
     return CPAN::Changes->load_string( 
         $self->changelog_file->content, 
-        next_token => qr/{{\$NEXT}}/
+        next_token => qr/\{\{\$NEXT\}\}/
     );
 }
 
@@ -55,7 +53,7 @@ Dist::Zilla::Role::Author::YANICK::Changelog - provides an accessor for the chan
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -108,7 +106,7 @@ Commit I<$changes> as the changelog file for the distribution.
 
 =head1 AUTHOR
 
-Yanick Champoux <yanick@babyl.dyndns.org>
+Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
