@@ -1,8 +1,6 @@
 package Dist::Zilla::Role::Author::YANICK::RequireZillaRole;
-BEGIN {
-  $Dist::Zilla::Role::Author::YANICK::RequireZillaRole::AUTHORITY = 'cpan:YANICK';
-}
-$Dist::Zilla::Role::Author::YANICK::RequireZillaRole::VERSION = '0.3.0';
+our $AUTHORITY = 'cpan:YANICK';
+$Dist::Zilla::Role::Author::YANICK::RequireZillaRole::VERSION = '0.4.0';
 use strict;
 use warnings;
 
@@ -58,11 +56,11 @@ Dist::Zilla::Role::Author::YANICK::RequireZillaRole
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 AUTHOR
 
-Yanick Champoux <yanick@babyl.dyndns.org>
+Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
